@@ -771,6 +771,16 @@ class ActorBase(ABC):
                 )
             return f"{msg_type}.{from_alias_lrh}.{from_role}.{type_name_lrh}.{radio_channel}"
 
+    def scada_routing_key(self, payload: HeartbeatA, to_g_node_alias: str) -> str:
+        if self.g_node_role != GNodeRole.AtomicTNode:
+            raise Exception(f"Only send messages to SCADA if role is AtomicTNode!")
+        msg_type = MessageCategorySymbol.gw.value
+        from_alias_lrh = self.alias.replace(".", "-")
+        type_name_lrh = payload.TypeName.replace(".", "-")
+
+        scada_routing_key = f"{msg_type}.{from_alias_lrh}.{type_name_lrh}"
+        return scada_routing_key
+
     def direct_routing_key(
         self, to_role: GNodeRole, payload: HeartbeatA, to_g_node_alias: str
     ) -> str:
@@ -784,30 +794,17 @@ class ActorBase(ABC):
         direct_routing_key = f"{msg_type}.{from_lrh_alias}.{from_role}.{type_name_lrh}.{to_role_val}.{to_lrh_alias}"
         return direct_routing_key
 
-    def type_name_from_routing_key(
-        self,
-        routing_key: str,
-    ) -> str:
-        """Returns the type alias of the message given the routing key. Raises a SchemaError
-        exception if there is a problem decoding the type alias, or if it does not have
-        the appropriate left-right-dot format.
+    def message_category_from_routing_key(self, routing_key: str) -> MessageCategory:
+        """Returns the MessageCategory of the message given the routing key.
 
-        For all the GNode Registry messages, this involves json dumping the payload
-        and looking for the TypeName dict key. However, in GridWorks World registries
-        where the participating entities represent TerminalAssets, AtomicTNodes, and
-        other operational actors in the electric grid model, there are a couple edge patterns
-        of routing key where the TypeName is a substring of the routing key itself.
-
-        The decision to embed the routing key INSIDE the body for the main set of
-        messages has to do with the length limit of 255 for rabbit routing keys, and
-        the desire to include both the FromGNodeAlias and the ToGNodeAlias in that key.
+        Raises a SchemaError exception if there is a problem decoding the MessageCategory
 
         Args:
-            routing_key (str): This is the basic_deliver.routing_key string
-            in a rabbit message
+           routing_key (str): This is the basic_deliver.routing_key string
+           in a rabbit message
 
         Returns:
-            str: the TypeName of the payload, in Lrd format
+           MessageCategory: the MessageCategory, as enum
         """
         routing_key_words = routing_key.split(".")
         if len(routing_key_words) < 4:
@@ -816,7 +813,6 @@ class ActorBase(ABC):
             )
             raise SchemaError(f"Routing key {routing_key} must have at least 3 words!")
         msg_category_symbol_value = routing_key_words[0]
-        type_name_lrh = routing_key_words[3]
 
         try:
             msg_category_symbol = MessageCategorySymbol(msg_category_symbol_value)
@@ -840,6 +836,29 @@ class ActorBase(ABC):
             raise SchemaError(
                 f"Rabbit messages do not handle {msg_category_symbol.value}"
             )
+        return msg_category
+
+    def type_name_from_routing_key(
+        self,
+        routing_key: str,
+    ) -> str:
+        """Returns the TypeName of the message given the routing key. Raises a SchemaError
+        exception if there is a problem decoding the TypeName, or if it does not have
+        the appropriate left-right-dot format.
+
+        Args:
+            routing_key (str): This is the basic_deliver.routing_key string
+            in a rabbit message
+
+        Returns:
+            str: the TypeName of the payload, in Lrd format
+        """
+        routing_key_words = routing_key.split(".")
+        msg_category = self.message_category_from_routing_key(routing_key)
+        if msg_category == MessageCategory.MqttJsonBroadcast:
+            type_name_lrh = routing_key_words[2]
+        else:
+            type_name_lrh = routing_key_words[3]
 
         if not property_format.is_lrh_alias_format(type_name_lrh):
             self._latest_on_message_diagnostic = (
@@ -862,7 +881,7 @@ class ActorBase(ABC):
         try:
             from_g_node_alias_lrh = routing_key_words[1]
         except:
-            raise SchemaError(f"{routing_key} must have at least three words!")
+            raise SchemaError(f"{routing_key} must have at least two words!")
 
         if not property_format.is_lrh_alias_format(from_g_node_alias_lrh):
             raise SchemaError(
@@ -884,6 +903,11 @@ class ActorBase(ABC):
         Returns:
             GNodeRole: GNodeRole of the actor that sent the message
         """
+        msg_category = self.message_category_from_routing_key(routing_key)
+        if msg_category == MessageCategory.MqttJsonBroadcast:
+            raise Exception(
+                "MqttJsonBroadcast does not contain FromRole in routing key"
+            )
         routing_key_words = routing_key.split(".")
         try:
             from_g_node_rabbit_role = routing_key_words[2]
@@ -893,7 +917,7 @@ class ActorBase(ABC):
             rabbit_role = RabbitRole(from_g_node_rabbit_role)
         except ValueError:
             raise SchemaError(
-                f"Unknown short alias {rabbit_role} in {routing_key}"
+                f"Unknown short alias {from_g_node_rabbit_role} in {routing_key}"
                 f" Must belong to {RabbitRole}"
             )
 
@@ -964,6 +988,10 @@ class ActorBase(ABC):
                 type=message_category.RabbitJsonBroadcast,
                 correlation_id=correlation_id,
             )
+        elif message_category is MessageCategory.MqttJsonBroadcast:
+            routing_key = self.scada_routing_key(
+                payload=payload, to_g_node_alias=to_g_node_alias
+            )
         else:
             raise Exception(f"Does not handle MessageCategory {message_category}")
 
@@ -1029,6 +1057,7 @@ class ActorBase(ABC):
         :param bytes body: The message body
         """
         self.latest_routing_key = basic_deliver.routing_key
+
         LOGGER.debug(
             f"{self.alias}: Got {basic_deliver.routing_key} with delivery tag {basic_deliver.delivery_tag}"
         )
@@ -1056,7 +1085,7 @@ class ActorBase(ABC):
             return
 
         routing_key: str = basic_deliver.routing_key
-
+        msg_category = self.message_category_from_routing_key(routing_key)
         try:
             from_alias = self.from_alias_from_routing_key(routing_key)
         except SchemaError as e:
@@ -1067,6 +1096,9 @@ class ActorBase(ABC):
                 f"IGNORING MESSAGE. {self._latest_on_message_diagnostic}: {e}"
             )
             return
+        if msg_category == MessageCategory.MqttJsonBroadcast:
+            self.route_mqtt_message(from_alias=from_alias, payload=payload)
+            return
         try:
             from_role = self.from_role_from_routing_key(routing_key)
         except SchemaError as e:
@@ -1102,6 +1134,10 @@ class ActorBase(ABC):
             except:
                 LOGGER.exception("Error in timestep_from_timecoordinator")
 
+    def route_mqtt_message(self, from_alias: str, payload: HeartbeatA) -> None:
+        """This router should be overwritten by derived class"""
+        ...
+
     ########################
     ## Time related (simulated time)
     ########################
